## 24.2.0.20240425 (2024-04-25)

Bump pyright to v1.1.360 (#11810)

## 24.2.0.20240315 (2024-03-15)

chore(deps): update pytype and pyright (#11595)

## 24.2.0.20240311 (2024-03-11)

Use Python 3.11 for third-party stubtest in CI (#11562)

Use PEP 570 syntax in third party stubs (#11554)

## 24.2.0.20240310 (2024-03-10)

Bump mypy to 1.9, add to json.encoder, small fixups (#11549)

Co-authored-by: Alex Waygood <Alex.Waygood@Gmail.com>

## 24.2.0.20240301 (2024-03-01)

Fix invalid noqa comments and poorly formatted type ignores (#11497)

## 24.2.0.20240218 (2024-02-18)

[stubsabot] Bump gevent to 24.2.* (#11425)

Release: https://pypi.org/pypi/gevent/24.2.1
Homepage: http://www.gevent.org/
Repository: https://github.com/gevent/gevent
Diff: https://github.com/gevent/gevent/compare/23.9.1...24.2.1

Stubsabot analysis of the diff between the two releases:
 - Total lines of Python code added: 4.
 - Total lines of Python code deleted: 4.

## 23.9.0.20240205 (2024-02-05)

A new shade of Black (#11362)

## 23.9.0.20240106 (2024-01-06)

Update typing_extensions imports in third-party stubs (#11245)

Remove Python 3.7 branches (#11238)

## 23.9.0.20240105 (2024-01-05)

Drop support for Python 3.7 (#11234)

## 23.9.0.1 (2023-12-11)

gevent: Use `TypeVarTuple` instead of old `ParamSpec` workaround. (#11129)

## 23.9.0.0 (2023-12-07)

Add stubs for gevent (#10527)

